@@ -23,10 +23,8 @@ import (
 
 	v2 "github.com/envoyproxy/go-control-plane/envoy/api/v2"
 	route "github.com/envoyproxy/go-control-plane/envoy/api/v2/route"
-	"github.com/envoyproxy/go-control-plane/pkg/cache"
-	"github.com/golang/protobuf/ptypes/wrappers"
-	"github.com/google/go-cmp/cmp/cmpopts"
-	"google.golang.org/protobuf/types/known/anypb"
+	"github.com/envoyproxy/go-control-plane/pkg/resource/v2"
+	"google.golang.org/protobuf/testing/protocmp"
 	"gotest.tools/v3/assert"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/client-go/kubernetes/fake"
@@ -38,15 +36,12 @@ func TestDeleteIngressInfo(t *testing.T) {
 	ctx := context.Background()
 
 	caches, err := NewCaches(ctx, &kubeClient, false)
-	if err != nil {
-		t.Fail()
-	}
+	assert.NilError(t, err)
 
 	// Add info for an ingress
 	firstIngressName := "ingress_1"
 	firstIngressNamespace := "ingress_1_namespace"
 	createTestDataForIngress(
-		ctx,
 		caches,
 		firstIngressName,
 		firstIngressNamespace,
@@ -59,7 +54,6 @@ func TestDeleteIngressInfo(t *testing.T) {
 	secondIngressName := "ingress_2"
 	secondIngressNamespace := "ingress_2_namespace"
 	createTestDataForIngress(
-		ctx,
 		caches,
 		secondIngressName,
 		secondIngressNamespace,
@@ -69,13 +63,22 @@ func TestDeleteIngressInfo(t *testing.T) {
 	)
 
 	// Delete the first ingress
-	_ = caches.DeleteIngressInfo(ctx, firstIngressName, firstIngressNamespace)
+	caches.DeleteIngressInfo(ctx, firstIngressName, firstIngressNamespace)
+
+	snapshot, err := caches.ToEnvoySnapshot(ctx)
+	assert.NilError(t, err)
+
+	routeConfigsR := snapshot.GetResources(resource.RouteType)
+	routeConfigs := make([]*v2.RouteConfiguration, len(routeConfigsR))
+	for _, r := range routeConfigsR {
+		routeConfigs = append(routeConfigs, r.(*v2.RouteConfiguration))
+	}
 
 	// Check that the listeners only have the virtual hosts of the second
 	// ingress.
 	// Note: Apart from the vHosts that were added explicitly, there's also
 	// the one used to verify the snapshot version.
-	vHostsNames := getVHostsNames(caches.routeConfig)
+	vHostsNames := getVHostsNames(routeConfigs)
 
 	sort.Strings(vHostsNames)
 
@@ -96,15 +99,12 @@ func TestDeleteIngressInfoWhenDoesNotExist(t *testing.T) {
 	ctx := context.Background()
 
 	caches, err := NewCaches(ctx, &kubeClient, false)
-	if err != nil {
-		t.Fail()
-	}
+	assert.NilError(t, err)
 
 	// Add info for an ingress
 	firstIngressName := "ingress_1"
 	firstIngressNamespace := "ingress_1_namespace"
 	createTestDataForIngress(
-		ctx,
 		caches,
 		firstIngressName,
 		firstIngressNamespace,
@@ -113,28 +113,22 @@ func TestDeleteIngressInfoWhenDoesNotExist(t *testing.T) {
 		"external_host_for_ingress_1",
 	)
 
-	snapshotBeforeDelete, err := caches.ToEnvoySnapshot()
-	if err != nil {
-		t.FailNow()
-	}
+	snapshotBeforeDelete, err := caches.ToEnvoySnapshot(ctx)
+	assert.NilError(t, err)
 
-	clustersBeforeDelete := snapshotBeforeDelete.GetResources(cache.ClusterType)
-	routesBeforeDelete := snapshotBeforeDelete.GetResources(cache.RouteType)
-	listenersBeforeDelete := snapshotBeforeDelete.GetResources(cache.ListenerType)
+	clustersBeforeDelete := snapshotBeforeDelete.GetResources(resource.ClusterType)
+	routesBeforeDelete := snapshotBeforeDelete.GetResources(resource.RouteType)
+	listenersBeforeDelete := snapshotBeforeDelete.GetResources(resource.ListenerType)
 
 	err = caches.DeleteIngressInfo(ctx, "non_existing_name", "non_existing_namespace")
-	if err != nil {
-		t.FailNow()
-	}
+	assert.NilError(t, err)
 
-	snapshotAfterDelete, err := caches.ToEnvoySnapshot()
-	if err != nil {
-		t.FailNow()
-	}
+	snapshotAfterDelete, err := caches.ToEnvoySnapshot(ctx)
+	assert.NilError(t, err)
 
-	clustersAfterDelete := snapshotAfterDelete.GetResources(cache.ClusterType)
-	routesAfterDelete := snapshotAfterDelete.GetResources(cache.RouteType)
-	listenersAfterDelete := snapshotAfterDelete.GetResources(cache.ListenerType)
+	clustersAfterDelete := snapshotAfterDelete.GetResources(resource.ClusterType)
+	routesAfterDelete := snapshotAfterDelete.GetResources(resource.RouteType)
+	listenersAfterDelete := snapshotAfterDelete.GetResources(resource.ListenerType)
 
 	// This is a temporary workaround. Remove when we delete the route with a
 	// randomly generated name in status_vhost.go
@@ -147,15 +141,14 @@ func TestDeleteIngressInfoWhenDoesNotExist(t *testing.T) {
 	vHostsRoutesAfter := routesAfterDelete["internal_services"].(*v2.RouteConfiguration).VirtualHosts
 	routesAfterDelete["internal_services"].(*v2.RouteConfiguration).VirtualHosts = vHostsRoutesAfter[:len(vHostsRoutesAfter)-1]
 
-	assert.DeepEqual(t, clustersBeforeDelete, clustersAfterDelete)
-	assert.DeepEqual(t, routesBeforeDelete, routesAfterDelete, cmpopts.IgnoreUnexported(wrappers.BoolValue{}))
-	assert.DeepEqual(t, listenersBeforeDelete, listenersAfterDelete, cmpopts.IgnoreUnexported(anypb.Any{}))
+	assert.DeepEqual(t, clustersBeforeDelete, clustersAfterDelete, protocmp.Transform())
+	assert.DeepEqual(t, routesBeforeDelete, routesAfterDelete, protocmp.Transform())
+	assert.DeepEqual(t, listenersBeforeDelete, listenersAfterDelete, protocmp.Transform())
 }
 
 // Creates an ingress translation and listeners from the given names an
 // associates them with the ingress name/namespace received.
 func createTestDataForIngress(
-	ctx context.Context,
 	caches *Caches,
 	ingressName string,
 	ingressNamespace string,
@@ -173,8 +166,7 @@ func createTestDataForIngress(
 		internalVirtualHosts: []*route.VirtualHost{{Name: internalVHostName, Domains: []string{internalVHostName}}},
 	}
 
-	_ = caches.addTranslatedIngress(translatedIngress)
-	_ = caches.setListeners(ctx)
+	caches.addTranslatedIngress(translatedIngress)
 }
 
 func TestValidateIngress(t *testing.T) {
@@ -182,12 +174,9 @@ func TestValidateIngress(t *testing.T) {
 	ctx := context.Background()
 
 	caches, err := NewCaches(ctx, &kubeClient, false)
-	if err != nil {
-		t.Fail()
-	}
+	assert.NilError(t, err)
 
 	createTestDataForIngress(
-		ctx,
 		caches,
 		"ingress_1",
 		"ingress_1_namespace",
