@@ -22,8 +22,7 @@ import (
 	route "github.com/envoyproxy/go-control-plane/envoy/api/v2/route"
 	extAuthService "github.com/envoyproxy/go-control-plane/envoy/config/filter/http/ext_authz/v2"
 	"github.com/envoyproxy/go-control-plane/pkg/wellknown"
-	"github.com/golang/protobuf/ptypes"
-	"github.com/golang/protobuf/ptypes/any"
+	"google.golang.org/protobuf/types/known/anypb"
 	"knative.dev/net-kourier/pkg/config"
 	envoy "knative.dev/net-kourier/pkg/envoy/api"
 )
@@ -38,13 +37,13 @@ func statusVHost() *route.VirtualHost {
 	)
 
 	// Make sure that ExtAuthz configuration is ignored on this path.
-	filter, _ := ptypes.MarshalAny(&extAuthService.ExtAuthzPerRoute{
+	filter, _ := anypb.New(&extAuthService.ExtAuthzPerRoute{
 		Override: &extAuthService.ExtAuthzPerRoute_Disabled{
 			Disabled: true,
 		},
 	})
 
-	vhost.TypedPerFilterConfig = map[string]*any.Any{
+	vhost.TypedPerFilterConfig = map[string]*anypb.Any{
 		wellknown.HTTPExternalAuthorization: filter,
 	}
 
