@@ -30,6 +30,7 @@ import (
 	"knative.dev/net-kourier/pkg/config"
 	envoy "knative.dev/net-kourier/pkg/envoy/server"
 	"knative.dev/net-kourier/pkg/generator"
+	rconfig "knative.dev/net-kourier/pkg/reconciler/ingress/config"
 	"knative.dev/networking/pkg/apis/networking/v1alpha1"
 	networkingClientSet "knative.dev/networking/pkg/client/clientset/versioned/typed/networking/v1alpha1"
 	knativeclient "knative.dev/networking/pkg/client/injection/client"
@@ -82,7 +83,14 @@ func NewController(ctx context.Context, cmw configmap.Watcher) *controller.Impl
 		extAuthz: config.ExternalAuthz.Enabled,
 	}
 
-	impl := v1alpha1ingress.NewImpl(ctx, r, config.KourierIngressClassName)
+	impl := v1alpha1ingress.NewImpl(ctx, r, config.KourierIngressClassName, func(impl *controller.Impl) controller.Options {
+		resync := configmap.TypeFilter(&config.Kourier{})(func(string, interface{}) {
+			impl.FilteredGlobalResync(isKourierIngress, ingressInformer.Informer())
+		})
+		configStore := rconfig.NewStore(logger.Named("config-store"), resync)
+		configStore.WatchConfigs(cmw)
+		return controller.Options{ConfigStore: configStore}
+	})
 
 	r.resyncConflicts = func() {
 		impl.FilteredGlobalResync(func(obj interface{}) bool {
