@@ -22,8 +22,6 @@ KOURIER_GATEWAY_NAMESPACE=kourier-system
 KOURIER_CONTROL_NAMESPACE=knative-serving
 TEST_NAMESPACE=serving-tests
 
-export KO_DOCKER_REPO=kind.local
-export KIND_CLUSTER_NAME="kourier-integration"
 $(dirname $0)/upload-test-images.sh
 
 echo ">> Setup test resources"
@@ -36,7 +34,7 @@ export "GATEWAY_OVERRIDE=kourier"
 export "GATEWAY_NAMESPACE_OVERRIDE=${KOURIER_GATEWAY_NAMESPACE}"
 
 echo "Install the old Kourier version"
-kubectl apply -f "https://github.com/knative-sandbox/net-kourier/releases/download/v0.19.1/release.yaml"
+kubectl apply -f "https://github.com/knative-sandbox/net-kourier/releases/download/v0.23.0/release.yaml"
 
 echo "Wait for all deployments to be up"
 kubectl -n "${KOURIER_CONTROL_NAMESPACE}" wait --timeout=300s --for=condition=Available deployment/3scale-kourier-control
@@ -57,13 +55,12 @@ until [[ $(kubectl -n "${TEST_NAMESPACE}" get ingresses.networking.internal.knat
 kubectl -n "${TEST_NAMESPACE}" wait --timeout=300s --for=condition=Ready ingresses.networking.internal.knative.dev --all
 
 echo "Install the current Kourier version"
-export KO_DOCKER_REPO=kind.local
 ko resolve -f config | \
   sed 's/LoadBalancer/NodePort/g' | \
   kubectl apply -f -
 
 echo "Wait for the deployments to roll over"
-kubectl -n "${KOURIER_CONTROL_NAMESPACE}" rollout status deployment/3scale-kourier-control
+kubectl -n "${KOURIER_CONTROL_NAMESPACE}" rollout status deployment/net-kourier-controller
 kubectl -n "${KOURIER_GATEWAY_NAMESPACE}" rollout status deployment/3scale-kourier-gateway
 
 echo "Wait for some more traffic to flow"
